@@ -10,7 +10,6 @@ from werkzeug.exceptions import MethodNotAllowed
 from pywps import get_ElementMakerForVersion
 import base64
 import datetime
-from pywps._compat import text_type, PY2
 from pywps.app.basic import get_xpath_ns
 from pywps.inout.inputs import input_from_json
 from pywps.exceptions import NoApplicableCode, OperationNotSupported, MissingParameterValue, VersionNegotiationFailed, \
@@ -87,10 +86,7 @@ class WPSRequest(object):
         try:
             doc = lxml.etree.fromstring(self.http_request.get_data())
         except Exception as e:
-            if PY2:
-                raise NoApplicableCode(e.message)
-            else:
-                raise NoApplicableCode(e.msg)
+            raise NoApplicableCode(e.msg)
 
         operation = doc.tag
         version = get_version_from_ns(doc.nsmap[doc.prefix])
@@ -191,7 +187,7 @@ class WPSRequest(object):
             acceptedversions = self.xpath_ns(
                 doc, '/wps:GetCapabilities/ows:AcceptVersions/ows:Version')
             acceptedversions = ','.join(
-                map(lambda v: v.text, acceptedversions))
+                [v.text for v in acceptedversions])
             wpsrequest.check_accepted_versions(acceptedversions)
 
             language = doc.attrib.get('language')
@@ -395,7 +391,7 @@ def get_inputs_from_xml(doc):
             value_el = literal_data[0]
             inpt = {}
             inpt['identifier'] = identifier_el.text
-            inpt['data'] = text_type(value_el.text)
+            inpt['data'] = str(value_el.text)
             inpt['uom'] = value_el.attrib.get('uom', '')
             inpt['datatype'] = value_el.attrib.get('datatype', '')
             the_inputs[identifier].append(inpt)
@@ -574,10 +570,7 @@ def _get_dataelement_value(value_el):
     """
 
     if isinstance(value_el, lxml.etree._Element):
-        if PY2:
-            return lxml.etree.tostring(value_el, encoding=unicode)  # noqa
-        else:
-            return lxml.etree.tostring(value_el, encoding=str)
+        return lxml.etree.tostring(value_el, encoding=str)
     else:
         return value_el
 
