@@ -30,6 +30,7 @@ import base64
 from collections import namedtuple
 from copy import deepcopy
 from io import BytesIO
+import humanize
 
 
 _SOURCE_TYPE = namedtuple('SOURCE_TYPE', 'MEMORY, FILE, STREAM, DATA, URL')
@@ -336,6 +337,11 @@ class FileHandler(IOHandler):
         import pathlib
         return pathlib.PurePosixPath(self.file).as_uri()
 
+    @property
+    def size(self):
+        """Length of the linked content in octets."""
+        return os.stat(self.file).st_size
+
     def _openmode(self, data=None):
         openmode = 'r'
         # in Python 3 we need to open binary files in binary mode.
@@ -441,12 +447,15 @@ class UrlHandler(FileHandler):
 
     @property
     def file(self):
+        """Downloads URL and return file pointer.
+        Checks if size is allowed before download.
+        """
         if self._file is not None:
             return self._file
 
         self._file = self._build_file_name(href=self.url)
 
-        max_byte_size = self.max_input_size()
+        max_byte_size = self.max_size()
 
         # Create request
         try:
@@ -455,21 +464,24 @@ class UrlHandler(FileHandler):
         except Exception as e:
             raise NoApplicableCode('File reference error: {}'.format(e))
 
-        error_message = 'File size for input "{}" exceeded. Maximum allowed: {} megabytes'.format(
-            self.inpt.get('identifier', '?'), max_byte_size)
+        error_message = 'File size for input "{}" exceeded. Maximum allowed: {}'.format(
+            self.inpt.get('identifier', '?'), humanize.naturalsize(max_byte_size))
 
-        if int(data_size) > int(max_byte_size):
-            raise FileSizeExceeded(error_message)
+        if int(max_byte_size) > 0:
+            if int(data_size) > int(max_byte_size):
+                raise FileSizeExceeded(error_message)
 
         try:
             with open(self._file, 'wb') as f:
                 data_size = 0
                 for chunk in reference_file.iter_content(chunk_size=1024):
                     data_size += len(chunk)
-                    if int(data_size) > int(max_byte_size):
-                        raise FileSizeExceeded(error_message)
+                    if int(max_byte_size) > 0:
+                        if int(data_size) > int(max_byte_size):
+                            raise FileSizeExceeded(error_message)
                     f.write(chunk)
-
+        except FileSizeExceeded:
+            raise
         except Exception as e:
             raise NoApplicableCode(e)
 
@@ -483,6 +495,16 @@ class UrlHandler(FileHandler):
     def post_data(self, value):
         self._post_data = value
 
+    @property
+    def size(self):
+        """Get content-length of URL without download"""
+        req = self._openurl(self.url)
+        if req.ok:
+            size = int(req.headers.get('content-length', '0'))
+        else:
+            size = 0
+        return size
+
     @staticmethod
     def _openurl(href, data=None):
         """Open given href.
@@ -496,14 +518,15 @@ class UrlHandler(FileHandler):
         return req
 
     @staticmethod
-    def max_input_size():
+    def max_size():
         """Calculates maximal size for input file based on configuration
         and units.
 
         :return: maximum file size in bytes
         """
         ms = config.get_config_value('server', 'maxsingleinputsize')
-        return config.get_size_mb(ms) * 1024**2
+        byte_size = config.get_size_mb(ms) * 1024**2
+        return byte_size
 
 
 class SimpleHandler(DataHandler):
